==> libtorrent_0.13.6.orig.tar.gz: libtorrent-0.13.6/src/torrent/utils/net.h <==
// libTorrent - BitTorrent library
// Copyright (C) 2005-2011, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#ifndef LIBTORRENT_UTILS_NET_H
#define LIBTORRENT_UTILS_NET_H

#include <netdb.h>
#include <tr1/functional>

namespace torrent {

typedef std::tr1::function<void (sockaddr*, socklen_t)> slot_ai_success;
//typedef std::tr1::function<void (const char*, int)>     slot_ai_failure;

// Throws address_info_error on lookup failure.
addrinfo*   address_info_lookup(const char* hostname, int family, int socktype);
inline void address_info_free(addrinfo* ai) { ::freeaddrinfo(ai); }

bool        address_info_call(addrinfo* ai, int flags, slot_ai_success slot_success);

}

#endif

==> libtorrent_0.13.8.orig.tar.gz: libtorrent-0.13.8/src/torrent/utils/net.h <==
// libTorrent - BitTorrent library
// Copyright (C) 2005-2011, Jari Sundell
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations
// including the two.
//
// You must obey the GNU General Public License in all respects for
// all of the code used other than OpenSSL.  If you modify file(s)
// with this exception, you may extend this exception to your version
// of the file(s), but you are not obligated to do so.  If you do not
// wish to do so, delete this exception statement from your version.
// If you delete this exception statement from all source files in the
// program, then also delete it here.
//
// Contact:  Jari Sundell <jaris@ifi.uio.no>
//
//           Skomakerveien 33
//           3185 Skoppum, NORWAY

#ifndef LIBTORRENT_UTILS_NET_H
#define LIBTORRENT_UTILS_NET_H

#include <netdb.h>
#include lt_tr1_functional

namespace torrent {

typedef std::function<void (sockaddr*, socklen_t)> slot_ai_success;
//typedef std::function<void (const char*, int)>     slot_ai_failure;

// Throws address_info_error on lookup failure.
addrinfo*   address_info_lookup(const char* hostname, int family, int socktype);
inline void address_info_free(addrinfo* ai) { ::freeaddrinfo(ai); }

bool        address_info_call(addrinfo* ai, int flags, slot_ai_success slot_success);

}

#endif
